Coverage for airflow.www.blueprints: 100%

# Coverage for airflow.www.blueprints : 100%

## 10 statements 10 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 | from flask import ( url_for, Markup, Blueprint, redirect, ) import chartkick import markdown # Init for chartkick, the python wrapper for highcharts ck = Blueprint( 'ck_page', __name__, static_folder=chartkick.js(), static_url_path='/static') routes = Blueprint('routes', __name__) @routes.route('/') def index(): return redirect(url_for('admin.index')) @routes.route('/health') def health(): """ We can add an array of tests here to check the server's health """ content = Markup(markdown.markdown("The server is healthy!")) return content